@@ -29,7 +29,9 @@ plot_fastest <- function(season = get_current_season(), round = 1, session = "R"
     cli::cli_abort("f1dataR::plot_fastest() requires ggplot2 package installation")
   }
   if (lifecycle::is_present(race)) {
-    lifecycle::deprecate_warn("1.0.0", "plot_fastest(race)", "plot_fastest(round)")
+    lifecycle::deprecate_stop("1.4.0", 
+                              "plot_fastest(race)", 
+                              "plot_fastest(round)")
     round <- race
   }
 
@@ -67,10 +69,8 @@ plot_fastest <- function(season = get_current_season(), round = 1, session = "R"
     )
   }
 
-  lim_min <- min(min(driver_data$x, na.rm = TRUE), min(driver_data$y, na.rm = TRUE))
-  lim_max <- max(max(driver_data$x, na.rm = TRUE), max(driver_data$y, na.rm = TRUE))
   if (color == "gear") {
-    ggplot2::ggplot(driver_data, ggplot2::aes(.data$x, .data$y, color = as.factor(.data$n_gear), group = 1)) +
+    fastplot <- ggplot2::ggplot(driver_data, ggplot2::aes(.data$x, .data$y, color = as.factor(.data$n_gear), group = 1)) +
       ggplot2::geom_path(linewidth = 4, lineend = "round") +
       ggplot2::scale_color_manual(
         name = "Gear",
@@ -78,24 +78,76 @@ plot_fastest <- function(season = get_current_season(), round = 1, session = "R"
         aesthetics = c("color", "fill")
       ) +
       theme_dark_f1() +
-      ggplot2::scale_x_continuous(limits = c(lim_min, lim_max)) +
-      ggplot2::scale_y_continuous(limits = c(lim_min, lim_max)) +
       ggplot2::labs(
         title = glue::glue("{year} {race_name}", year = season, race = race_name),
         subtitle = glue::glue("{driver} Fastest Lap | {lap_time}", driver = driver, lap_time = lap_time),
         caption = "Generated by {f1dataR} package"
       )
   } else if (color == "speed") {
-    ggplot2::ggplot(driver_data, ggplot2::aes(.data$x, .data$y, color = .data$speed, group = 1)) +
+    fastplot <- ggplot2::ggplot(driver_data, ggplot2::aes(.data$x, .data$y, color = .data$speed, group = 1)) +
       ggplot2::geom_path(linewidth = 4, lineend = "round") +
       ggplot2::scale_color_gradient(low = "white", high = "red") +
       theme_dark_f1() +
-      ggplot2::scale_x_continuous(limits = c(lim_min, lim_max)) +
-      ggplot2::scale_y_continuous(limits = c(lim_min, lim_max)) +
       ggplot2::labs(
         title = glue::glue("{year} {race_name}", year = season, race = race_name),
         subtitle = glue::glue("{driver} Fastest Lap | {lap_time}", driver = driver, lap_time = lap_time),
         caption = "Generated by {f1dataR} package"
       )
   }
+  return(correct_track_ratio(fastplot))
+}
+
+
+#' Correct Track Ratios
+#'
+#' @description
+#' Correct Track Ratios helps ensure that ggplot objects are plotted with 1:1 unit ratio.
+#' Without this function, plots have different x & y ratios and the tracks come out misshapen.
+#' This is particularly evident at long tracks like Saudi Arabia or Canada.
+#'
+#' Note that this leaves the plot object on a dark background, any plot borders will be maintained
+#'
+#' @param trackplot A GGPlot object, ideally showing a track layout for ratio correction
+#' @param x,y Names of columns in the original data used for the plot's x and y values.
+#' Defaults to 'x' and 'y'
+#' @param background Background colour to use for filling out the plot edges. Defaults to
+#' `"grey10"` which is the default background colour if you use \code{\link[f1dataR]{theme_dark_f1}()}
+#' to theme your plots.
+#'
+#' @return a ggplot object with `ggplot2::scale_x_continuous()` and `ggplot2::scale_y_continuous()` set to the
+#' same limits to produce an image with shared x and y limits and with `ggplot2::coord_fixed()` set.
+#'
+#' @export
+#' @examples
+#' \dontrun{
+#' # Note that plot_fastest plots have already been ratio correctedF
+#' fast_plot <- plot_fastest(season = 2022, round = 1, session = "Q", driver = V)
+#' correct_track_ratio(fast_plot)
+#' }
+correct_track_ratio <- function(trackplot, x = "x", y = "y", background = "grey10") {
+  if (!"ggplot" %in% class(trackplot)) {
+    cli::cli_abort("{.var trackplot} must be a `ggplot` object")
+  }
+  if (!requireNamespace("ggplot2", quietly = TRUE)) {
+    cli::cli_abort("f1dataR::correct_track_ratio() requires ggplot2 package installation")
+  }
+
+  plotdata <- trackplot$data
+
+  # centre the data
+  trackplot$data[[x]] <- trackplot$data[[x]] - stats::median(trackplot$data[[x]], na.rm = TRUE)
+  trackplot$data[[y]] <- trackplot$data[[y]] - stats::median(trackplot$data[[y]], na.rm = TRUE)
+
+  # determine limits and apply to plot
+  lim_min <- min(min(trackplot$data[[x]], na.rm = TRUE), min(trackplot$data[[y]], na.rm = TRUE))
+  lim_max <- max(max(trackplot$data[[x]], na.rm = TRUE), max(trackplot$data[[y]], na.rm = TRUE))
+
+  trackplot <- trackplot +
+    ggplot2::scale_x_continuous(limits = c(lim_min, lim_max)) +
+    ggplot2::scale_y_continuous(limits = c(lim_min, lim_max)) +
+    ggplot2::coord_fixed()
+
+  # ensure the letterbox filler is a nice colour
+  grid::grid.rect(gp = grid::gpar(fill = background, col = background))
+  plot(trackplot, newpage = FALSE)
 }
